pywws.TimeZone — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# pywws.TimeZone

## Introduction

Ce module fournit deux objets `datetime.tzinfo` représentant l’heure UTC et fuseaux horaires locaux. Ceux-ci sont utilisés pour convertir vers et depuis l’heure UTC et l’heure locale. Les logiciels de stations météorologiques emmagasinent les données horodatées en UTC, pour éviter les problèmes avec l’heure d’été, mais le gabarit et les données des graphes sont affichés avec les heures locales.

Le module est copié directement de la documentation du module `datetime.tzinfo`.

## API détaillé

Fournit un couple d’objets datetime.tzinfo () représentant l’heure locale et UTC.

Copiés directement à partir de la documentation du module datetime.

Classes

`LocalTimezone` | Local time
`UTC` | UTC

class `pywws.TimeZone.` `UTC`

  UTC

  `utcoffset`(dt)
  `tzname`(dt)
  `dst`(dt)

class `pywws.TimeZone.` `LocalTimezone`

  Local time

  `utcoffset`(dt)
  `dst`(dt)
  `tzname`(dt)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »